Welcome to ClientVPS Mirrors

Help for package CTAShiny
Type: Package
Title: Interactive Application for Working with Contingency Tables
Version: 0.1.0
Author: Kartikeya Bolar
Maintainer: Kartikeya Bolar <kartikeya.bolar@tapmi.edu.in>
Description: An interactive application for working with contingency Tables. The application has a template for solving contingency table problems like chisquare test of independence,association plot between two categorical variables. Runtime examples are provided in the package function as well as at https://jarvisatharva.shinyapps.io/CategoricalDataAnalysis/.
License: GPL-2
Encoding: UTF-8
LazyData: TRUE
Depends: R (≥ 3.0.3)
Imports: shiny,shinyMatrix,epitools,rpivotTable
RoxygenNote: 6.1.0
NeedsCompilation: no
Packaged: 2019-04-12 08:47:04 UTC; KARTIKEYA
Repository: CRAN
Date/Publication: 2019-04-13 08:22:55 UTC

Launch CTAShiny Interface

Description

CTAShiny() loads interactive user interface built using R shiny.

Usage

CTAShiny()

Details

Start CTAShiny

The interactive user interface is to provide an easy way for people who are learning Contingency Table Analysis. Includes example data for testing out a few example analysis.

Value

Nothing

Examples

if(interactive()){
library(shiny)
CTAShiny()
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.